@@ -140,8 +140,8 @@ def add_domain(domain):
     subprocess.call(["sudo", "service", "nginx", "restart"])
 
     web.generate_cert(domain)
-    subprocess.call(["cp", f"certs/{domain}/domain.key", "/etc/ssl/private"])
-    subprocess.call(["cp", f"certs/{domain}/domain.crt", "/etc/ssl/certs"])
+    subprocess.call(["sudo", "cp", f"certs/{domain}/domain.key", "/etc/ssl/private"])
+    subprocess.call(["sudo", "cp", f"certs/{domain}/domain.crt", "/etc/ssl/certs"])
 
     domains[domain] = True
     with nginx_conf_path.open("w") as fp:
